@@ -14,6 +14,7 @@ from nanpy.serialmanager import SerialManager
 from nanpy.serialmanager import serial_manager
 
 from nanpy.arduino import Arduino
+from nanpy.eeprom import EEPROM
 from nanpy.lcd import Lcd
 from nanpy.onewire import OneWire
 from nanpy.stepper import Stepper
@@ -21,3 +22,6 @@ from nanpy.servo import Servo
 from nanpy.dallastemperature import DallasTemperature
 from nanpy.tone import Tone
 from nanpy.capacitivesensor import CapacitiveSensor
+from nanpy.dht import DHT
+from nanpy.arduinoapi import ArduinoApi
+from nanpy.eepromobj import EepromLib
