@@ -3,8 +3,8 @@ from nanpy.arduinoboard import (arduinoobjectmethod, returns)
 
 class Servo(ArduinoObject):
 
-    def __init__(self, pin):
-        ArduinoObject.__init__(self)
+    def __init__(self, pin, connection=None):
+        ArduinoObject.__init__(self, connection=connection)
         self.id = self.call('new', pin)
 
     @arduinoobjectmethod
